import django

dj3 = (3,) <= django.VERSION < (4,)
dj4 = (4,) <= django.VERSION < (5,)
dj_ge4 = django.VERSION >= (4,)
dj_ge41 = django.VERSION >= (4, 1)
dj_ge42 = django.VERSION >= (4, 2)
dj_ge5 = django.VERSION >= (5,)
